OPICS reference documentation
================================

For an introduction to OPICS, start at the 
`OPICS GitHub page <https://github.com/SiEPIC/OPICS>`_.


.. toctree::
   :maxdepth: 2
   :caption: Quickstart

   install

.. toctree::
   :maxdepth: 2
   :caption: Libraries

   opics.lib.ebeam

.. toctree::
   :maxdepth: 2
   :caption: Tutorials
   
   notebooks/01-Mach-Zehnder_Interferometer
   notebooks/02-Micro_Ring_Resonator

.. toctree::
   :maxdepth: 2
   :caption: Notes

   authors

.. toctree::
   :maxdepth: 3
   :caption: API documentation

   opics



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

